precision highp float;

uniform sampler2D tex;
uniform vec4 quadSize;
uniform vec2 gradientSize;

uniform vec4 backgroundColor;
uniform vec4 outlineColor;

varying vec2 fTexCoord;
varying vec4 fColor;

vec3 getOutlineColor(vec4 srcColor, float t)
{
    //calculate linear fade factor
    float l = 1.0 - abs(t * 2.0 - 1.0);
    
    //calculate bright for outline
    float b = l * l * 8.0 * srcColor.a;
    
    return mix(srcColor.rgb, outlineColor.rgb * b, float(l > 0.0));
}

vec2 calculateQuadGradient(vec2 absTexCoords)
{
    vec2 halfTextureSize = quadSize.xy * 0.5;
    vec2 pixelPerfectUvs = absTexCoords * halfTextureSize;
    return smoothstep(halfTextureSize - gradientSize.xy, halfTextureSize, pixelPerfectUvs);
}

void main()
{
    //текстурные координаты в диапазоне [-1.0; 1.0]
    vec2 mapUvs = fTexCoord * 2.0 - 1.0;
    
    //абсолютное значение текстурных координат в диапазоне [1.0; 0.0; 1.0]
    vec2 absUvs = abs(mapUvs);
    
    vec2 quadGradient = calculateQuadGradient(absUvs);
    float fade = max(quadGradient.x, quadGradient.y);
    
    vec4 outputColor = backgroundColor;
    outputColor.a *= fade;
    
    outputColor.rgb = getOutlineColor(outputColor, fade);
    
    //считаем ореол
    gl_FragColor = outputColor;
}
